"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.CommentUserActionBuilder = void 0;

var _lodash = require("lodash");

var _so_references = require("../../../attachment_framework/so_references");

var _api = require("../../../../common/api");

var _abstract_builder = require("../abstract_builder");

var _so_references2 = require("../../so_references");

/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */
class CommentUserActionBuilder extends _abstract_builder.UserActionBuilder {
  build(args) {
    var _args$action;

    const soExtractor = (0, _so_references2.getAttachmentSOExtractor)(args.payload.attachment);
    const {
      transformedFields,
      references: refsWithExternalRefId
    } = soExtractor.extractFieldsToReferences({
      data: args.payload.attachment
    });
    const {
      attributes: extractedAttributes,
      references: extractedReferences
    } = (0, _so_references.extractPersistableStateReferencesFromSO)(transformedFields, {
      persistableStateAttachmentTypeRegistry: this.persistableStateAttachmentTypeRegistry
    });
    const commentUserAction = this.buildCommonUserAction({ ...args,
      action: (_args$action = args.action) !== null && _args$action !== void 0 ? _args$action : _api.Actions.update,
      valueKey: 'comment',
      value: { ...transformedFields,
        ...extractedAttributes
      },
      type: _api.ActionTypes.comment
    });
    return { ...commentUserAction,
      references: (0, _lodash.uniqBy)([...commentUserAction.references, ...refsWithExternalRefId, ...extractedReferences], 'id')
    };
  }

}

exports.CommentUserActionBuilder = CommentUserActionBuilder;