"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.setupConnectorsIndices = exports.SETUP_ERRORS = void 0;

var _ = require("..");

var _identify_exceptions = require("../utils/identify_exceptions");

/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */
let SETUP_ERRORS;
exports.SETUP_ERRORS = SETUP_ERRORS;

(function (SETUP_ERRORS) {
  SETUP_ERRORS[SETUP_ERRORS["insufficient_permissions"] = 0] = "insufficient_permissions";
  SETUP_ERRORS[SETUP_ERRORS["index_already_exists"] = 1] = "index_already_exists";
})(SETUP_ERRORS || (exports.SETUP_ERRORS = SETUP_ERRORS = {}));

const connectorMappingsProperties = {
  api_key_id: {
    type: 'keyword'
  },
  configuration: {
    type: 'object'
  },
  error: {
    type: 'keyword'
  },
  index_name: {
    type: 'keyword'
  },
  language: {
    type: 'keyword'
  },
  last_seen: {
    type: 'date'
  },
  last_sync_error: {
    type: 'keyword'
  },
  last_sync_status: {
    type: 'keyword'
  },
  last_synced: {
    type: 'date'
  },
  name: {
    type: 'keyword'
  },
  scheduling: {
    properties: {
      enabled: {
        type: 'boolean'
      },
      interval: {
        type: 'text'
      }
    }
  },
  service_type: {
    type: 'keyword'
  },
  status: {
    type: 'keyword'
  },
  sync_now: {
    type: 'boolean'
  }
};
const defaultSettings = {
  auto_expand_replicas: '0-3',
  hidden: true,
  number_of_replicas: 0
};
const indices = [{
  aliases: ['.elastic-connectors'],
  mappings: {
    _meta: {
      version: '1'
    },
    properties: connectorMappingsProperties
  },
  name: '.elastic-connectors-v1',
  settings: defaultSettings
}, {
  aliases: ['.elastic-connectors-sync-jobs'],
  mappings: {
    _meta: {
      version: '1'
    },
    properties: {
      completed_at: {
        type: 'date'
      },
      connector: {
        properties: connectorMappingsProperties
      },
      connector_id: {
        type: 'keyword'
      },
      created_at: {
        type: 'date'
      },
      deleted_document_count: {
        type: 'integer'
      },
      error: {
        type: 'keyword'
      },
      indexed_document_count: {
        type: 'integer'
      },
      status: {
        type: 'keyword'
      },
      worker_hostname: {
        type: 'keyword'
      }
    }
  },
  name: '.elastic-connectors-sync-jobs-v1',
  settings: defaultSettings
}];

const createConnectorsIndex = async (client, indexDefinition) => {
  try {
    const {
      aliases,
      mappings,
      name: index,
      settings
    } = indexDefinition;
    await client.indices.create({
      index,
      mappings,
      settings
    });
    await client.indices.updateAliases({
      actions: [{
        add: {
          aliases,
          index,
          is_hidden: true,
          is_write_index: true
        }
      }]
    });
  } catch (error) {
    if ((0, _identify_exceptions.isResourceAlreadyExistsException)(error)) {
      // We hit a race condition, do nothing
      return;
    }

    return error;
  }
};

const setupConnectorsIndices = async client => {
  const connectorsIndexResponse = await client.indices.get({
    index: `${_.CONNECTORS_INDEX}*`
  });

  for (const indexDefinition of indices) {
    if (!connectorsIndexResponse[indexDefinition.name]) {
      await createConnectorsIndex(client, indexDefinition);
    } // TODO handle migrations once we start migrating stuff

  }
};

exports.setupConnectorsIndices = setupConnectorsIndices;