"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createGetMonitorStatusRoute = void 0;

var _configSchema = require("@kbn/config-schema");

var _saved_objects = require("../../../common/types/saved_objects");

var _constants = require("../../../common/constants");

var _runtime_types = require("../../../common/runtime_types");

/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */
const queryParams = _configSchema.schema.object({
  monitorId: _configSchema.schema.string(),
  dateStart: _configSchema.schema.string(),
  dateEnd: _configSchema.schema.string()
});

const createGetMonitorStatusRoute = libs => ({
  method: 'GET',
  path: _constants.SYNTHETICS_API_URLS.MONITOR_STATUS,
  validate: {
    query: queryParams
  },
  handler: async ({
    uptimeEsClient,
    request,
    server,
    savedObjectsClient
  }) => {
    const {
      monitorId,
      dateStart,
      dateEnd
    } = request.query;
    const latestMonitor = await libs.requests.getLatestMonitor({
      uptimeEsClient,
      monitorId,
      dateStart,
      dateEnd
    });

    if (latestMonitor.docId) {
      return latestMonitor;
    }

    if (!server.savedObjectsClient) {
      return null;
    }

    try {
      const {
        saved_objects: [monitorSavedObject]
      } = await savedObjectsClient.find({
        type: _saved_objects.syntheticsMonitorType,
        perPage: 1,
        page: 1,
        filter: `${_saved_objects.syntheticsMonitorType}.id: "${_saved_objects.syntheticsMonitorType}:${monitorId}" OR ${_saved_objects.syntheticsMonitorType}.attributes.${_runtime_types.ConfigKey.CUSTOM_HEARTBEAT_ID}: "${monitorId}"`
      });

      if (!monitorSavedObject) {
        return null;
      }

      const {
        [_runtime_types.ConfigKey.URLS]: url,
        [_runtime_types.ConfigKey.NAME]: name,
        [_runtime_types.ConfigKey.HOSTS]: host,
        [_runtime_types.ConfigKey.MONITOR_TYPE]: type
      } = monitorSavedObject.attributes;
      return {
        url: {
          full: url || host
        },
        monitor: {
          name,
          type,
          id: monitorSavedObject.id
        }
      };
    } catch (e) {
      server.logger.error(e);
    }
  }
});

exports.createGetMonitorStatusRoute = createGetMonitorStatusRoute;